@@ -19,6 +19,7 @@ import asyncio
 from hypercorn.config import Config
 from hypercorn.asyncio import serve
 from grpc import StatusCode
+from urllib.parse import urlparse
 
 supported_methods = ['get', 'put', 'post', 'delete', 'patch']
 
@@ -47,7 +48,8 @@ class AccessLogMiddleware(BaseHTTPMiddleware):
   async def dispatch(self, request, call_next):
     response = await call_next(request)
     if response.status_code < 400:
-      logging.info(f'[{response.status_code}] {request.method} {request.url}')
+      path = urlparse(request.url).path
+      logging.info(f'[{response.status_code}] {request.method} {path}')
     return response
 
 
@@ -84,7 +86,8 @@ class GatewayServer(threading.Thread):
 
   async def http_exception(self, request, exc):
     if 'favicon.ico' not in str(request.url):
-      logging.error(f'[{exc.status_code}] {request.method} {request.url} - {exc.detail}')
+      path = urlparse(request.url).path
+      logging.error(f'[{exc.status_code}] {request.method} {path} - {exc.detail}')
     return JSONResponse({'detail': exc.detail, 'status': exc.status_code}, status_code=exc.status_code)
 
   def run(self) -> None:
